function [ Xc ] = outlier( X,npc )
%[ I,Xc ] = outlier( X,npc )
%   INPUT:
%   X = data matrix
%   npc = number of PCs for PCA
%   OUTPUT:
%   I = outlier indeces
%   Xc = data matrix without outliers
%   --
%   Camilo L. M. Morais
%   cdlmedeiros-de-morai@uclan.ac.uk
%   University of Central Lancashire, 2018

I = [];
Xc = X;

Xmc = meancenter(X);
[T,P] = pca(Xmc,npc);

[T2,Q] = stat(Xmc,T,P);

figure,
plot(T2,Q,'o')
xlabel('Hotelling T2');
ylabel('Q residuals');
title('Before Outlier Removal');
disp('-----------------');
T2_thr = input('Select the Hotelling T2 threshold: ');
Q_thr = input('Select the Q residuals threshold: ');
REP = input('Select the number of repetitions: ');
disp('-----------------');
disp('Removed samples:');
disp(' ');
REP = double(REP);

A = Xmc;

for i=1:REP
    if max(T2) > T2_thr 
        [a,b] = max(T2);
        Xc(b,:)=[];
        A(b,:)=[];
        disp(b);
    end
    [T,P] = pca(A,npc);
    [T2,Q] = stat(A,T,P);
end

for i=1:REP
if max(Q) > Q_thr 
        [a,b] = max(Q);
        Xc(b,:)=[];
        A(b,:)=[];
        disp(b);
end
    [T,P] = pca(A,npc);
    [T2,Q] = stat(A,T,P);
end

disp('-----------------');  
[T,P] = pca(Xc,npc);
[T2,Q] = stat(Xc,T,P);
figure,
plot(T2,Q,'o')
xlabel('Hotelling T2');
ylabel('Q residuals');
title('After Outlier Removal');

end

